@@ -3,18 +3,20 @@ from unittest import TestLoader, TestSuite, TextTestRunner
 from pythautomata.tests.test_minimizer import TestMinimizer
 from pythautomata.tests.test_automata_convertor import TestAutomataConvertor
 from pythautomata.tests.test_pdfa_generator import TestPDFAGenerator
-from pythautomata.tests.test_simple_DFA_generator import TestSimpleDFAGenerator
+from pythautomata.tests.test_pdfa_serialization import TestPDFASerialization
+from pythautomata.tests.test_DFA_generators import TestDFAGenerators
 from pythautomata.tests.test_automata_comparison import TestAutomataComparison
 from pythautomata.tests.test_sequence import TestSequence
 from pythautomata.tests.test_dfa_operations import TestDFAOperations
 from pythautomata.tests.test_automata_definitions import TestAutomataDefinitions
 from pythautomata.tests.test_regex_generator import TestRegexGenerator
 
+
 def get_all_tests():
-    return [TestPDFAGenerator, TestMinimizer, TestAutomataConvertor, 
-    TestSimpleDFAGenerator, TestAutomataComparison, TestSequence,
-    TestDFAOperations, TestAutomataDefinitions, TestPDFAGenerator,
-    TestRegexGenerator]
+    return [TestPDFAGenerator, TestMinimizer, TestAutomataConvertor,
+            TestDFAGenerators, TestAutomataComparison, TestSequence,
+            TestDFAOperations, TestAutomataDefinitions, TestPDFAGenerator,
+            TestRegexGenerator, TestPDFASerialization]
 
 
 def run():
